@@ -482,11 +482,12 @@ class Waveform(object):
                 for model_id in self.order:
                     # Prepare model coupling
                     self.prepare_model_coupling(old_state, model_id, t_frame)
-
+                # Start threads
                 with ThreadPoolExecutor() as executor:
                     for model_id in self.order:
-                        executor.submit(self.compute_model, model_id)
-                                    
+                        tasks.append(executor.submit(self.compute_model, model_id))
+                    executor.shutdown(wait=True)
+
             # Compute convergence for every model and
             # all of its output variables
             convergence_iter = self.compute_convergence(
